@@ -11,11 +11,11 @@ where no better keyring is available.
 
 =head1 VERSION
 
-Version 0.2405
+Version 1.0000
 
 =cut
 
-our $VERSION = '0.2405';
+our $VERSION = '1.0000';
 
 =head1 SYNOPSIS
 
@@ -141,8 +141,8 @@ Marcin Kasperski
 
 =head1 BUGS
 
-Please report any bugs or feature requests to 
-issue tracker at L<https://bitbucket.org/Mekk/perl-keyring-memory>.
+Please report any bugs or feature requests to
+issue tracker at L<https://helixteamhub.cloud/mekk/projects/perl/issues>.
 
 =head1 SUPPORT
 
@@ -156,11 +156,11 @@ L<http://search.cpan.org/~mekk/Passwd-Keyring-Memory/>
 
 Source code is tracked at:
 
-L<https://bitbucket.org/Mekk/perl-keyring-memory>
+L<https://helixteamhub.cloud/mekk/projects/perl/repositories/keyring-memory>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Marcin Kasperski.
+Copyright 2012-2020 Marcin Kasperski.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
